@@ -4,7 +4,7 @@ SCons Packaging Tool.
 """
 
 #
-# Copyright (c) 2001 - 2018 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -25,7 +25,7 @@ SCons Packaging Tool.
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-__revision__ = "src/engine/SCons/Tool/packaging/__init__.py 8bcbf788a94dd8067ab0e5bccf1c0f0e9bc62a76 2019-01-01 00:03:08 bdbaddog"
+__revision__ = "src/engine/SCons/Tool/packaging/__init__.py e724ae812eb96f4858a132f5b8c769724744faf6 2019-07-21 00:04:47 bdeegan"
 
 import SCons.Defaults
 import SCons.Environment
@@ -35,11 +35,11 @@ from SCons.Util import is_List, make_path_relative
 from SCons.Warnings import warn, Warning
 
 import os
-import imp
+import importlib
 
 __all__ = [
-    'src_targz', 'src_tarbz2', 'src_xz', 'src_zip',
-    'targz', 'tarbz2', 'xz', 'zip',
+    'src_targz', 'src_tarbz2', 'src_tarxz', 'src_zip',
+    'targz', 'tarbz2', 'tarxz', 'zip',
     'rpm', 'msi', 'ipk',
 ]
 
@@ -122,12 +122,12 @@ def Package(env, target=None, source=None, **kw):
     # load the needed packagers.
     def load_packager(type):
         try:
-            file,path,desc=imp.find_module(type, __path__)
-            return imp.load_module(type, file, path, desc)
+            # the specific packager is a relative import
+            return importlib.import_module("." + type, __name__)
         except ImportError as e:
-            raise EnvironmentError("packager %s not available: %s"%(type,str(e)))
+            raise SConsEnvironmentError("packager %s not available: %s" % (type, str(e)))
 
-    packagers=list(map(load_packager, PACKAGETYPE))
+    packagers = list(map(load_packager, PACKAGETYPE))
 
     # set up targets and the PACKAGEROOT
     try:
